@@ -11,7 +11,8 @@ def cluster(sample, ratio, distance, quality, threads, **kwargs):
 
     extracted_csv = pipeline / f"{sample}.barcodes.q{quality}.tsv"
 
-    input_file = extract_csv_column(extracted_csv, 2)
+    if not extracted_csv.with_suffix(".c2.tsv").is_file():
+        input_file = extract_csv_column(extracted_csv, 2)
 
     output_file = pipeline / f"{sample}.barcodes.q{quality}.r{ratio}d{distance}.tsv"
 
@@ -29,7 +30,15 @@ def cluster(sample, ratio, distance, quality, threads, **kwargs):
         )
         if kwargs["verbose"]:
             console.print("[yellow]STARCODE OUTPUT:")
-            console.print(p.stdout)
+            console.print(
+                "\n".join(
+                    [
+                        line
+                        for line in p.stdout.splitlines()
+                        if not line.startswith("progress")
+                    ]
+                )
+            )
 
         console.log(f"[green]{sample}[/green]: clustering complete")
 
