@@ -10,7 +10,6 @@ from .utils import fastq_to_csv
 def extract(
     sample,
     fastq,
-    sourcedir,
     error_rate,
     threads,
     barcode_length,
@@ -23,28 +22,34 @@ def extract(
 ):
 
     pipeline = Path(kwargs["pipelinedir"])
-    barcode_fastq = pipeline / f"{sample}.barcode.fastq"
+    json_qc = pipeline / "qc" / f"{sample}.json"
+    html_qc = pipeline / "qc" / f"{sample}.html"
+    # barcode_fastq = pipeline / f"{sample}.barcode.fastq"
     input_file = fastq
-    filtered_barcode_fastq = pipeline / f"{sample}.barcode.q{quality}.fastq"
+    # filtered_barcode_fastq = pipeline / f"{sample}.barcode.q{quality}.fastq"
+    filtered_fastq = pipeline / f"{sample}.q{quality}.fastq"
+    filtered_barcode_fastq = pipeline / f"{sample}.q{quality}.barcode.fastq"
 
     if unlinked_adapters:
         adapter_string = f"-g {upstream_adapter} -a {downstream_adapter}"
     else:
         adapter_string = f"-g {upstream_adapter}...{downstream_adapter}"
 
+    (pipeline / "qc").mkdir(exist_ok=True)
+
     if not filtered_barcode_fastq.is_file():
 
         console.log(f"[green]{sample}[/green]: extracting and filtering barcodes")
 
-        command = f"cutadapt \
-            -e {error_rate} \
-            -j {threads} \
-            --minimum-length={min_barcode_length} \
-            --maximum-length={barcode_length} \
-            --max-n=0 \
-            --trimmed-only {adapter_string} \
-            -n 2 \
-            -o {barcode_fastq} {input_file}"
+        command = f"fastp \
+            -i {input_file} \
+            -o {filtered_fastq} \
+            -q {quality} \
+            -u 80 \
+            -w {threads} \
+            -h {html_qc} \
+            -j {json_qc} \
+            --dont_eval_duplication"
 
         args = shlex.split(command)
 
@@ -55,7 +60,37 @@ def extract(
             universal_newlines=True,
         )
 
-        if barcode_fastq.stat().st_size == 0:
+        if p.returncode != 0:
+            console.print("[yellow]FASTP OUTPUT:")
+            console.print(f"[green]{sample}[/green]: fastp failed")
+            console.print(p.stdout)
+            sys.exit(1)
+
+        elif kwargs["verbose"]:
+            console.print("[yellow]FASTP OUTPUT:")
+            console.print(p.stdout)
+
+        command = f"cutadapt \
+            -e {error_rate} \
+            -j {threads} \
+            --minimum-length={min_barcode_length} \
+            --maximum-length={barcode_length} \
+            --max-n=0 \
+            --trimmed-only \
+            {adapter_string} \
+            -n 2 \
+            -o {filtered_barcode_fastq} {filtered_fastq}"
+
+        args = shlex.split(command)
+
+        p = subprocess.run(
+            args,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
+            universal_newlines=True,
+        )
+
+        if filtered_barcode_fastq.stat().st_size == 0:
             console.print("[yellow]CUTADAPT OUTPUT:")
             console.print(p.stdout)
             console.print(
@@ -68,18 +103,7 @@ def extract(
             console.print("[yellow]CUTADAPT OUTPUT:")
             console.print(p.stdout)
 
-        command = f"fastq_quality_filter \
-            -q {quality} \
-            -p 100 \
-            -Q 33 \
-            -i {barcode_fastq} \
-            -o {filtered_barcode_fastq}"
-
-        args = shlex.split(command)
-
-        p = subprocess.run(args)
-
-        barcode_fastq.unlink()
+        # barcode_fastq.unlink()
 
         console.log(f"[green]{sample}[/green]: extraction and filtering complete")
 
